Learn R Programming

DIFshiny (version 0.1.0)

DIFshiny: Launches the shiny app to perform DIF Analysis.

Description

By using the functions in this package without any arguments, you can perform your Differential Item Functioning (DIF) analysis with user-friendly shiny interfaces.

Usage

DIFshiny()

Arguments

Value

No return value, launches application

Examples

Run this code
# NOT RUN {
 if(interactive()){

 DIFshiny()

 }
# }

Run the code above in your browser using DataLab