powered by
By using the functions in this package without any arguments, you can perform your Differential Item Functioning (DIF) analysis with user-friendly shiny interfaces.
DIFshiny()
No return value, launches application
# NOT RUN { if(interactive()){ DIFshiny() } # }
Run the code above in your browser using DataLab